===========
base module
===========

.. automodule:: musixmatch.base

   .. autoclass:: Base
      :show-inheritance:
      :members: label, apiMethod

   .. autoclass:: Item
      :show-inheritance:

   .. autoclass:: ItemsCollection
      :show-inheritance:
      :members: copy, page, pages, pager, paged, fromResponseMessage, allowedin
